@@ -2,7 +2,7 @@
 """
 import pytest
 from psychopy.tests.utils import skip_under_travis
-from psychopy.tests.test_iohub.testutil import startHubProcess, stopHubProcess
+from psychopy.tests.test_iohub.testutil import startHubProcess, stopHubProcess, getTime
 
 @skip_under_travis
 def testDefaultServerLaunch():
@@ -13,7 +13,10 @@ def testDefaultServerLaunch():
     # check that a kb and mouse have been created
     keyboard=io.devices.keyboard
     mouse=io.devices.mouse
+    exp = io.devices.experiment
     assert keyboard != None
     assert mouse != None
+    assert exp != None
+
     stopHubProcess()
 
